@@ -10,7 +10,7 @@ use Scalar::Util qw(blessed);
 
 BEGIN { $BASE_EXC_CLASS ||= 'Exception::Class::Base'; }
 
-$VERSION = '1.21';
+$VERSION = '1.22';
 
 sub import
 {
@@ -378,6 +378,12 @@ sub isa
 }
 EOF
 
+sub caught
+{
+    return Exception::Class->caught(shift);
+}
+
+
 1;
 
 __END__
@@ -407,15 +413,16 @@ Exception::Class - A module that allows you to declare real exception classes in
   # try
   eval { MyException->throw( error => 'I feel funny.' ) };
 
+  my $e;
   # catch
-  if ( UNIVERSAL::isa( $@, 'MyException' ) )
+  if ( $e = Exception::Class->caught('MyException') )
   {
      warn $@->error, "\n, $@->trace->as_string, "\n";
      warn join ' ',  $@->euid, $@->egid, $@->uid, $@->gid, $@->pid, $@->time;
 
      exit;
   }
-  elsif ( UNIVERSAL::isa( $@, 'ExceptionWithFields' ) )
+  elsif ( $e = Exception::Class->caught('ExceptionWithFields') )
   {
      $@->quixotic ? do_something_wacky() : do_something_sane();
   }
@@ -554,6 +561,14 @@ function uses C<eval>, or calls something which uses it, then C<$@> is
 overwritten.  Copying the exception preserves it for the call to
 C<do_something_with_exception()>.
 
+Exception objects also provide a caught method so you can write:
+
+ if ( my $e = My::Error->caught() )
+ {
+     cleanup();
+     do_something_with_exception($e);
+ }
+
 =head2 Uncatchable Exceptions
 
 Internally, the C<caught()> method will call C<isa()> on the exception
